Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(289)

Unified Diff: recipes/ios.py

Issue 21428002: Add fetch recipe targeting iOS (Closed) Base URL: https://chromium.googlesource.com/chromium/tools/depot_tools.git@master
Patch Set: Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « recipes/chromium.py ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: recipes/ios.py
diff --git a/recipes/android.py b/recipes/ios.py
similarity index 65%
copy from recipes/android.py
copy to recipes/ios.py
index efc78a32abcc3410bc2297b92c4c020e639d7832..e7ee08b6d569a4efb867feaf4b4c09d163b78437 100644
--- a/recipes/android.py
+++ b/recipes/ios.py
@@ -1,4 +1,4 @@
-# Copyright (c) 2013 The Chromium Authors. All rights reserved.
+# Copyright 2013 The Chromium Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
@@ -9,21 +9,21 @@ import recipe_util # pylint: disable=F0401
# This class doesn't need an __init__ method, so we disable the warning
# pylint: disable=W0232
-class Android(recipe_util.Recipe):
- """Basic Recipe alias for Android -> Chromium."""
+class IOS(recipe_util.Recipe):
+ """Basic Recipe alias for iOS -> Chromium."""
@staticmethod
def fetch_spec(props):
return {
'alias': {
'recipe': 'chromium',
- 'props': ['--target_os=android'],
+ 'props': ['--target_os=ios', '--target_os_only=True'],
},
}
def main(argv=None):
- return Android().handle_args(argv)
+ return IOS().handle_args(argv)
if __name__ == '__main__':
« no previous file with comments | « recipes/chromium.py ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698